#-----------------------------------------------------
# Ohl, Brandt, & Kliegl (2013) - Journal of Vision
# Figure 2
#-----------------------------------------------------

#------------------------------------------------------
# load packages and functions
rm(list=ls())
library(ggplot2)
library(grid)
library(lme4)
library(MASS)
library(lattice)

source("remef.R")

load("Ohl_JoV_2013.Rdata")
#------------------------------------------------------

#------------------------------------
# define colors (see also rgb and col2rgb)
deforange <- rgb(255,150,0,max=255)
defgreen  <- rgb(100,255,100,max=255)
defblue   <- rgb(0,150,255,max=255)
#------------------------------------

#------------------------------------------------------
# Run linear mixed model (LMM)
summary(res2 <- lmer(latency ~ ecccond*(sacerror_hor+sacerror_hor2) + (1+sacerror_hor+sacerror_hor2+ecccond|vp),data=d),REML=FALSE)
#------------------------------------------------------

#------------------------------------------------------
# Construct Plot

# Remove subject variance
d$latency_adjusted <- remef(res2, fix = c(), ran = list(1:4))

# Use ggplot2
figlatency <- ggplot(d,aes(x=sacerror_hor,y=latency_adjusted))
figlatency <- figlatency  + geom_smooth(aes(colour=eccentricity,linetype=eccentricity),size=1.2,alpha=0.8)
#figlatency <- figlatency + geom_point(aes(colour=eccentricity))
#figlatency <- figlatency + geom_line(aes(x=sacerror_hor,y=latency,linetype=eccentricity,colour=eccentricity),size=1.2,data=out)
figlatency <- figlatency + scale_colour_manual(values=c("red","blue"))
figlatency <- figlatency + scale_linetype_manual(values=c(1,2))
figlatency <- figlatency + geom_vline(xintercept=0)
figlatency <- figlatency + ylim(0,700)
figlatency <- figlatency + xlim(quantile(d$sacerror_hor,probs=c(0.025,0.975)))
figlatency <- figlatency + annotate("text", x = -1, y = 650, label = "undershoot",size=8)
figlatency <- figlatency + annotate("text", x = 1, y = 650, label = "overshoot",size=8)
figlatency <- figlatency + xlab("Primary saccade error [in ]") + ylab("Secondary saccade latency [ms]") + theme_bw(base_size=16)
figlatency <- figlatency + opts(legend.position=c(0.3,0.25))
figlatency <- figlatency + opts(legend.text=theme_text(size=16))
figlatency <- figlatency + opts(legend.title=theme_blank())
#figlatency <- figlatency + opts(legend.position="none")
figlatency <- figlatency + opts(panel.grid.major=theme_line(colour=NA))
figlatency <- figlatency + opts(panel.grid.minor=theme_line(colour=NA))
#------------------------------------------------------