#-----------------------------------------------------
# Ohl, Brandt, & Kliegl (2013) - Journal of Vision
# Figure 3
#-----------------------------------------------------

#------------------------------------------------------
# load packages and functions
rm(list=ls())
library(ggplot2)
library(grid)
library(lme4)
library(MASS)
library(lattice)

source("remef.R")

load("Ohl_JoV_2013.Rdata")
#------------------------------------------------------

#------------------------------------
# define colors (see also rgb and col2rgb)
deforange <- rgb(255,150,0,max=255)
defgreen  <- rgb(100,255,100,max=255)
defblue   <- rgb(0,150,255,max=255)
#------------------------------------

#------------------------------------------------------
# choose only same and opposite movements
d <- d[which(d$direction=="same" | d$direction=="opposite"),]
d$direction <- ifelse(d$direction=="same",0,1)
table(d$direction)
#------------------------------------------------------

#------------------------------------------------------
# Run linear mixed model (LMM)

# FULL MODEL
summary(res2 <- glmer(direction ~ ecccond*(sacerror_hor) + (1+sacerror_hor+ecccond|vp),data=d,family=binomial),REML=FALSE)
#------------------------------------------------------

#------------------------------------------------------
# get estimates based on coef from LMM

	# get predictions of the model "res2"
	estimates <- coef(res2)$vp[1,]
	estimates[1] <- fixef(res2)[[1]]
	estimates[2] <- fixef(res2)[[2]]
	estimates[3] <- fixef(res2)[[3]]
	estimates[4] <- fixef(res2)[[4]]

	error_hor <- seq(min(d$sacerror_hor),max(d$sacerror_hor),length.out=200)
	
	modelestimate<-function(e_hor,cdt)
	{
	direction <- estimates[[1]] + cdt*estimates[[2]] + e_hor*estimates[[3]] + 	
	e_hor*cdt*estimates[[4]]


	# logistic regression ->  1/(1+exp(-modelestimate))
	direction <- 1/(1+exp((-1)*direction))

	eccentricity <- rep(cdt,times=length(e_hor))
	
	out <- cbind(direction,e_hor,eccentricity)
	}

	# predict:
	out1 <- modelestimate(error_hor,0)	# close target undershoot
	out2 <- modelestimate(error_hor,1)	# distant target undershoot


	# put predictions together
	out  <- as.data.frame(rbind(out1,out2))
	out$eccentricity <- as.factor(out$eccentricity)
	levels(out$eccentricity) <- c("close target","distant target")
	colnames(out) <- c("direction","sacerror_hor","eccentricity")
#------------------------------------------------------

#------------------------------------------------------
# Plot (Choose between smooth, remef, predictions)

# remove subject variance
d$direction_adjusted <- remef(res2, fix = c(), ran = list(1:3))

# start plotting
figdirection <- ggplot(d,aes(x=sacerror_hor,y=direction))
#figdirection <- figdirection + geom_smooth(aes(colour=eccentricity),size=1.2,alpha=0.5)
figdirection <- figdirection + geom_hline(yintercept=0)
figdirection <- figdirection + geom_hline(yintercept=1)
figdirection <- figdirection + geom_point(aes(x=sacerror_hor,y=direction,colour=eccentricity),alpha=0.8,size=1,position=position_jitter(height=0.05))
figdirection <- figdirection + geom_line(aes(x=sacerror_hor,y=direction,colour=eccentricity,linetype=eccentricity),size=1.2,data=out)
figdirection <- figdirection + scale_colour_manual(values=c("red","blue"))
figdirection <- figdirection + scale_linetype_manual(values=c(1,2))
figdirection <- figdirection + geom_vline(xintercept=0) + ylim(0,1)
figdirection <- figdirection + xlim(quantile(d$sacerror_hor,probs=c(0.025,0.975))) + ylim(-0.1,1.1)
figdirection <- figdirection + xlab("Primary saccade error [in ]") + ylab("P(secondary saccade in opposite direction)") + theme_bw(base_size=16)
figdirection <- figdirection + opts(legend.position=c(0.25,0.5))
figdirection <- figdirection + opts(legend.text=theme_text(size=16))
figdirection <- figdirection + opts(legend.title=theme_blank())
figdirection <- figdirection + opts(panel.grid.major=theme_line(colour=NA))
figdirection <- figdirection + opts(panel.grid.minor=theme_line(colour=NA))
#------------------------------------------------------