#-----------------------------------------------------
# Ohl, Brandt, & Kliegl (2013) - Journal of Vision
# Figure 4
#-----------------------------------------------------

#------------------------------------------------------
# load packages and functions
rm(list=ls())
library(ggplot2)
library(grid)
library(reshape)
library(lme4)
library(MASS)
library(lattice)

source("remef.R")

load("Ohl_JoV_2013.Rdata")
#------------------------------------------------------

#------------------------------------------------------
# Generate new variabel
d$sacerror_hor_abs <- abs(d$sacerror_hor)

# Plot primary saccade error vs. secondary saccade error
fyi <- ggplot(d,aes(x=sacerror_hor,y=error_hor))+facet_grid(.~eccentricity)
fyi <- fyi + geom_point(size=0.4)#+geom_smooth()
fyi <- fyi + ylim(quantile(d$sacerror_hor,probs=c(0.01,0.99)))
#fyi <- fyi + geom_vline(xintercept=0) 
#fyi <- fyi + geom_hline(yintercept=0) 
fyi <- fyi + geom_density2d(size=2)
fyi <- fyi + xlab("Primary saccade error [in ]")+ylab("Secondary saccade error [in ]")
fyi <- fyi + theme_bw(base_size=16)
fyi <- fyi + opts(strip.background = theme_rect(colour = "white"))

# can we see something in the densities
d2 <- rbind(data.frame(error = d$sacerror_hor,ecc = d$eccentricity,cond=rep("PSE",times=nrow(d)),vp=d$vp),data.frame(error = d$error_hor,ecc=d$eccentricity,cond=rep("SSE",times=nrow(d)),vp=d$vp))

fyi2 <- ggplot(d2,aes(x=error,color=cond))+facet_grid(.~ecc)+geom_density()


# Is primary saccade error larger than secondary saccade error?
d2$error_abs <- abs(d2$error)
m1 <- melt(d2,id=c("vp","ecc","cond"),measure=c("error_abs"))
c1 <- cast(m1,vp+ecc+cond ~ variable,mean)
m2 <- melt(c1,id=c("ecc","cond"),measure=c("error_abs"))
c2 <- cast(m2,ecc+cond ~ variable,c(mean,length,sd))

# make a few of the above analysis without correct primary saccades
idx <- which(d$sacerror_hor_abs>=1)
dx <- d[idx,]
d3 <- rbind(data.frame(error = dx$sacerror_hor,ecc = dx$eccentricity,cond=rep("PSE",times=nrow(dx)),vp=dx$vp),data.frame(error = dx$error_hor,ecc=dx$eccentricity,cond=rep("SSE",times=nrow(dx)),vp=dx$vp))

fyi3 <- ggplot(d3,aes(x=error,color=cond))+facet_wrap(~ecc,ncol=1)+geom_density()+xlim(quantile(d$sacerror_hor,probs=c(0.025,0.975)))

d3$error_abs <- abs(d3$error)
m1 <- melt(d3,id=c("vp","ecc","cond"),measure=c("error_abs"))
c1 <- cast(m1,vp+ecc+cond ~ variable,mean)
m2 <- melt(c1,id=c("ecc","cond"),measure=c("error_abs"))
c2 <- cast(m2,ecc+cond ~ variable,c(mean,length,sd))
#------------------------------------------------------

#------------------------------------------------------
# choose only same and opposite movements
d <- d[which(d$direction=="same" | d$direction=="opposite"),]
d$direction <- ifelse(d$direction=="same",0,1)
table(d$direction)
#------------------------------------------------------

#------------------------------------------------------
# prepare variables for signed analysis and plots
idx <- which(d$direction==1)
d$amplitude_signed <- d$amplitude
d$amplitude_signed[idx] <- d$amplitude[idx] * (-1)
plot(d$amplitude_signed,d$amplitude)
plot(d$sacerror_hor,d$amplitude_signed,xlim=c(-3.5,3.5),ylim=c(-3.5,3.5))
abline(h=0,col="red"); abline(v=0,col="red")
#------------------------------------------------------

#------------------------------------------------------
# Run linear mixed model (LMM)

# FULL MODEL
summary(res2 <- lmer(amplitude_signed ~ ecccond*sacerror_hor + (1+sacerror_hor+ecccond|vp),data=d),REML=FALSE)
#------------------------------------------------------

#------------------------------------------------------
# remove subject variance
d$amplitude_signed_adjusted <- remef(res2, fix = c(), ran = list(1:3))

# start plot
figamplitude <- ggplot(d,aes(x=sacerror_hor,y=amplitude_signed_adjusted))	#...y=amplitude_adjusted))
figamplitude <- figamplitude + geom_vline(xintercept=0,size=1,col="black") + ylim(-3.5,4)
figamplitude <- figamplitude + geom_hline(yintercept=0,size=1,col="black") + xlim(-2.5,2.5)
figamplitude <- figamplitude + geom_abline(intercept = 0, slope = -1,size=1.5,col="grey")
figamplitude <- figamplitude + geom_point(aes(colour=eccentricity),size=0.7,alpha=1)
figamplitude <- figamplitude + geom_smooth(aes(colour=eccentricity,linetype=eccentricity),size=1.2,alpha=1)
figamplitude <- figamplitude + scale_colour_manual(values=c("red","blue"))
figamplitude <- figamplitude + scale_linetype_manual(values=c(1,2))
figamplitude <- figamplitude + annotate("text", x = -1.2, y = 3.8, label = "undershoot",size=8)
figamplitude <- figamplitude + annotate("text", x = 1.2, y = 3.8, label = "overshoot",size=8)
figamplitude <- figamplitude + xlab("Primary saccade error [in ]") + ylab("Secondary saccade amplitude [in ]") + theme_bw(base_size=16)
figamplitude <- figamplitude + opts(legend.position=c(0.3,0.25))
figamplitude <- figamplitude + opts(legend.title=theme_blank())
figamplitude <- figamplitude + opts(panel.grid.major=theme_line(colour=NA))
figamplitude <- figamplitude + opts(panel.grid.minor=theme_line(colour=NA))
#------------------------------------------------------