#-----------------------------------------------------
# Ohl, Brandt, & Kliegl (2013) - Journal of Vision
# Figure 5, 6, and 7
#-----------------------------------------------------

#------------------------------------------------------
# load packages and functions
rm(list=ls())
library(ggplot2)
library(reshape)
library(grid)
library(lme4)
library(MASS)
library(lattice)

source("remef.R")

load("Ohl_JoV_2013.Rdata")
#------------------------------------------------------

#------------------------------------------------------
# choose only same and opposite movements
d <- d[which(d$direction=="same" | d$direction=="opposite"),]
d$direction <- ifelse(d$direction=="same",0,1)
table(d$direction)
#------------------------------------------------------

#------------------------------------------------------
# Remove outliers
rm_crit1 <- quantile(d$sacerror_hor,probs=c(0.015,0.985))
rm_crit2 <- quantile(d$error_hor,probs=c(0.015,0.985))

idx <- which(d$sacerror_hor >= rm_crit1[[1]] & 
		 d$sacerror_hor <= rm_crit1[[2]] & 
		 d$error_hor >= rm_crit2[[1]] & 
		 d$sacerror_hor <= rm_crit2[[2]])
d <- d[idx,]

d$sacerror_hor_abs <- abs(d$sacerror_hor)

# Make two separate data sets
d_close   <- d[d$eccentricity == "close target",]
d_distant <- d[d$eccentricity == "distant target",]
#------------------------------------------------------


#------------------------------------------------------
# Plot Figure 5

fig0c1 <- ggplot(d_close,aes(x=sacerror_hor,y=error_hor))
fig0c1 <- fig0c1 + geom_point() + geom_density2d(size=1)
fig0c1 <- fig0c1 + theme_bw(base_size=16) + opts(strip.background = theme_rect(colour = "white"))
fig0c1 <- fig0c1 + xlab("Primary saccade error [in ]") + annotate("text", x = -1, y = 3.5, label = "close target",size=5) 
fig0c1 <- fig0c1 + ylab("Secondary saccade error [in ]")

fig0c2 <- ggplot(d_distant,aes(x=sacerror_hor,y=error_hor))
fig0c2 <- fig0c2 + geom_point() + geom_density2d(size=1)
fig0c2 <- fig0c2 + theme_bw(base_size=16) + opts(strip.background = theme_rect(colour = "white"))
fig0c2 <- fig0c2 + xlab("Primary saccade error [in ]") + annotate("text", x = -1, y = 3.5, label = "distant target",size=5) 
fig0c2 <- fig0c2 + ylab("Secondary saccade error [in ]")

#pdf("Figure5.pdf", width = 10, height = 5)
grid.newpage()
pushViewport(viewport(layout = grid.layout(1, 2)))
vplayout <- function(x, y) 
  viewport(layout.pos.row = x, layout.pos.col = y)
	print(fig0c1, vp = vplayout(1, 1))
	print(fig0c2, vp = vplayout(1, 2))
#dev.off()
#----------------------------------------------------------

#----------------------------------------------------------
# Make an extra data frame for trials with primary saccade error larger than 1
idx <- which(d$sacerror_hor_abs>=1)
dx <- d[idx,]
d3 <- rbind(data.frame(error = dx$sacerror_hor,ecc = dx$eccentricity,cond=rep("PSE",times=nrow(dx)),vp=dx$vp),data.frame(error = dx$error_hor,ecc=dx$eccentricity,cond=rep("SSE",times=nrow(dx)),vp=dx$vp))
d3_close   <- d3[d3$ecc == "close target",]
d3_distant <- d3[d3$ecc == "distant target",]

# package for close targets
d3_close_sacerror_hist <- hist(d3_close$error[d3_close$cond=="PSE"],breaks=seq(-3,4,by=1/4)-0.125)
d3_close_error_hist    <- hist(d3_close$error[d3_close$cond=="SSE"],breaks=seq(-3,4,by=1/4)-0.125)
xmat_close_sacerror <- cbind(d3_close_sacerror_hist$mids,d3_close_sacerror_hist$counts)
xmat_close_error    <- cbind(d3_close_error_hist$mids,d3_close_error_hist$counts)

# package for distant targets
d3_distant_sacerror_hist <- hist(d3_distant$error[d3_distant$cond=="PSE"],breaks=seq(-3,4,by=1/4)-0.125)
d3_distant_error_hist    <- hist(d3_distant$error[d3_distant$cond=="SSE"],breaks=seq(-3,4,by=1/4)-0.125)
xmat_distant_sacerror    <- cbind(d3_distant_sacerror_hist$mids,d3_distant_sacerror_hist$counts)
xmat_distant_error       <- cbind(d3_distant_error_hist$mids,d3_distant_error_hist$counts)


#pdf("Figure7.pdf",width=10,height=5)
par(mfrow=c(1,2),mar=c(2,1,1,1))
xlimval <- 105
linevalues <- barplot(xmat_close_sacerror[,2]*(-1),horiz=TRUE,xlim=c(-xlimval,xlimval),
		axes=FALSE,main="CLOSE TARGET",col="red")
		
		# add second barplot -> secondary saccade error
		barplot(xmat_close_error[,2],horiz=TRUE,axes=FALSE,col="red",add=TRUE)

		# add two vertical lines
		lines(c(-xlimval+25,-xlimval+25),c(min(linevalues),max(linevalues)))
		lines(c(xlimval-25,xlimval-25),c(min(linevalues),max(linevalues)))

		# add some horizontal lines
		linemat <- cbind(xmat_close_sacerror[,1],linevalues,xmat_close_sacerror[,1])
		linemat <- linemat[c(1,5,9,13,17,21,25),]
		for (i in 1:nrow(linemat)){
		lines(c(-80,80),c(linemat[i,2],linemat[i,2]),lty=2,col="grey")
		}
		for (i in 1:nrow(linemat)){
		lines(c(-xlimval+25-2,-xlimval+25+2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		lines(c(xlimval-25+2,xlimval-25-2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		text(-xlimval+25,linemat[i,2],as.character(linemat[i,1]),pos=2)
		text(xlimval-25,linemat[i,2],as.character(linemat[i,1]),pos=4)
		}

		# line that seperates the two distributions
		lines(c(0,0),c(0,linevalues[length(linevalues)]),lwd=2.5,col="black")

		# add labeling
		text(-xlimval+6,linemat[4,2],"Primary saccade error [in ]",srt=90,cex=1.2)
		text(xlimval-6,linemat[4,2],"Secondary saccade error [in ]",srt=-90,cex=1.2)


		xlimval <- 105
linevalues <- barplot(xmat_distant_sacerror[,2]*(-1)*(0.6),horiz=TRUE,xlim=c(-xlimval,xlimval),
		axes=FALSE,main="DISTANT TARGET",col="blue")
		#points(xmat_close_sacerror[,2]*(-1),linevalues,col="black")
		
		# add second barplot -> secondary saccade error
		barplot(xmat_distant_error[,2]*(0.6),horiz=TRUE,axes=FALSE,col="blue",add=TRUE)

		# add two vertical lines
		lines(c(-xlimval+25,-xlimval+25),c(min(linevalues),max(linevalues)))
		lines(c(xlimval-25,xlimval-25),c(min(linevalues),max(linevalues)))

		# add some horizontal lines
		linemat <- cbind(xmat_distant_sacerror[,1],linevalues,xmat_distant_sacerror[,1])
		linemat <- linemat[c(1,5,9,13,17,21,25),]
		for (i in 1:nrow(linemat)){
		lines(c(-80,80),c(linemat[i,2],linemat[i,2]),lty=2,col="grey")
		}
		for (i in 1:nrow(linemat)){
		lines(c(-xlimval+25-2,-xlimval+25+2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		lines(c(xlimval-25+2,xlimval-25-2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		text(-xlimval+25,linemat[i,2],as.character(linemat[i,1]),pos=2)
		text(xlimval-25,linemat[i,2],as.character(linemat[i,1]),pos=4)
		}

		# line that seperates the two distributions
		lines(c(0,0),c(0,linevalues[length(linevalues)]),lwd=2.5,col="black")

		# add labeling
		text(-xlimval+6,linemat[4,2],"Primary saccade error [in ]",srt=90,cex=1.2)
		text(xlimval-6,linemat[4,2],"Secondary saccade error [in ]",srt=-90,cex=1.2)

	#----------------------------------------------------------
#dev.off()


### make the same once again for the full data set
d2 <- rbind(data.frame(error = d$sacerror_hor,ecc = d$eccentricity,cond=rep("PSE",times=nrow(d)),vp=d$vp),data.frame(error = d$error_hor,ecc=d$eccentricity,cond=rep("SSE",times=nrow(d)),vp=d$vp))
d2_close   <- d2[d2$ecc == "close target",]
d2_distant <- d2[d2$ecc == "distant target",]

# package for close targets
d2_close_sacerror_hist <- hist(d2_close$error[d2_close$cond=="PSE"],breaks=seq(-3,4,by=1/4)-0.125)
d2_close_error_hist    <- hist(d2_close$error[d2_close$cond=="SSE"],breaks=seq(-3,4,by=1/4)-0.125)
xmat_close_sacerror <- cbind(d2_close_sacerror_hist$mids,d2_close_sacerror_hist$counts)
xmat_close_error    <- cbind(d2_close_error_hist$mids,d2_close_error_hist$counts)

# package for distant targets
d2_distant_sacerror_hist <- hist(d2_distant$error[d2_distant$cond=="PSE"],breaks=seq(-3,4,by=1/4)-0.125)
d2_distant_error_hist    <- hist(d2_distant$error[d2_distant$cond=="SSE"],breaks=seq(-3,4,by=1/4)-0.125)
xmat_distant_sacerror    <- cbind(d2_distant_sacerror_hist$mids,d2_distant_sacerror_hist$counts)
xmat_distant_error       <- cbind(d2_distant_error_hist$mids,d2_distant_error_hist$counts)


#pdf("Figure6.pdf",width=10,height=5)
par(mfrow=c(1,2),mar=c(2,1,1,1))
		xlimval <- 105
linevalues <- barplot(xmat_close_sacerror[,2]*(-1)*(0.4),horiz=TRUE,xlim=c(-xlimval,xlimval),
		axes=FALSE,main="CLOSE TARGET",col="red")
		#points(xmat_close_sacerror[,2]*(-1)*(0.4),linevalues,col="black")
		
		# add second barplot -> secondary saccade error
		barplot(xmat_close_error[,2]*(0.4),horiz=TRUE,axes=FALSE,col="red",add=TRUE)

		# add two vertical lines
		lines(c(-xlimval+25,-xlimval+25),c(min(linevalues),max(linevalues)))
		lines(c(xlimval-25,xlimval-25),c(min(linevalues),max(linevalues)))

		# add some horizontal lines
		linemat <- cbind(xmat_close_sacerror[,1],linevalues,xmat_close_sacerror[,1])
		linemat <- linemat[c(1,5,9,13,17,21,25),]
		for (i in 1:nrow(linemat)){
		lines(c(-80,80),c(linemat[i,2],linemat[i,2]),lty=2,col="grey")
		}
		for (i in 1:nrow(linemat)){
		lines(c(-xlimval+25-2,-xlimval+25+2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		lines(c(xlimval-25+2,xlimval-25-2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		text(-xlimval+25,linemat[i,2],as.character(linemat[i,1]),pos=2)
		text(xlimval-25,linemat[i,2],as.character(linemat[i,1]),pos=4)
		}

		# line that seperates the two distributions
		lines(c(0,0),c(0,linevalues[length(linevalues)]),lwd=2.5,col="black")

		# add labeling
		text(-xlimval+6,linemat[4,2],"Primary saccade error [in ]",srt=90,cex=1.2)
		text(xlimval-6,linemat[4,2],"Secondary saccade error [in ]",srt=-90,cex=1.2)


		xlimval <- 105
linevalues <- barplot(xmat_distant_sacerror[,2]*(-1)*(0.35),horiz=TRUE,xlim=c(-xlimval,xlimval),
		axes=FALSE,main="DISTANT TARGET",col="blue")
		#points(xmat_close_sacerror[,2]*(-1),linevalues,col="black")
		
		# add second barplot -> secondary saccade error
		barplot(xmat_distant_error[,2]*(0.35),horiz=TRUE,axes=FALSE,col="blue",add=TRUE)

		# add two vertical lines
		lines(c(-xlimval+25,-xlimval+25),c(min(linevalues),max(linevalues)))
		lines(c(xlimval-25,xlimval-25),c(min(linevalues),max(linevalues)))

		# add some horizontal lines
		linemat <- cbind(xmat_distant_sacerror[,1],linevalues,xmat_distant_sacerror[,1])
		linemat <- linemat[c(1,5,9,13,17,21,25),]
		for (i in 1:nrow(linemat)){
		lines(c(-80,80),c(linemat[i,2],linemat[i,2]),lty=2,col="grey")
		}
		for (i in 1:nrow(linemat)){
		lines(c(-xlimval+25-2,-xlimval+25+2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		lines(c(xlimval-25+2,xlimval-25-2),c(linemat[i,2],linemat[i,2]),lty=1,col="black")
		text(-xlimval+25,linemat[i,2],as.character(linemat[i,1]),pos=2)
		text(xlimval-25,linemat[i,2],as.character(linemat[i,1]),pos=4)
		}

		# line that seperates the two distributions
		lines(c(0,0),c(0,linevalues[length(linevalues)]),lwd=2.5,col="black")

		# add labeling
		text(-xlimval+6,linemat[4,2],"Primary saccade error [in ]",srt=90,cex=1.2)
		text(xlimval-6,linemat[4,2],"Secondary saccade error [in ]",srt=-90,cex=1.2)

	#----------------------------------------------------------
#dev.off()